@@ -3,7 +3,7 @@
   | Suhosin Version 1                                                    |
   +----------------------------------------------------------------------+
   | Copyright (c) 2006-2007 The Hardened-PHP Project                     |
-  | Copyright (c) 2007-2014 SektionEins GmbH                             |
+  | Copyright (c) 2007-2015 SektionEins GmbH                             |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
@@ -257,22 +257,11 @@ SDEBUG("xxx %p %p",SUHOSIN_G(include_whitelist),SUHOSIN_G(include_blacklist));
 }
 
 
-#ifdef ZEND_ENGINE_2
 static int (*old_zend_stream_open)(const char *filename, zend_file_handle *fh TSRMLS_DC);
-#else
-static zend_bool (*old_zend_open)(const char *filename, zend_file_handle *fh);
-#endif
 
-#ifdef ZEND_ENGINE_2
 static int suhosin_zend_stream_open(const char *filename, zend_file_handle *fh TSRMLS_DC)
 {
 	zend_execute_data *exd;
-#else
-static zend_bool suhosin_zend_open(const char *filename, zend_file_handle *fh)
-{
-	zend_execute_data *exd;
-	TSRMLS_FETCH();
-#endif
 	exd=EG(current_execute_data);
 	if (EG(in_execution) && (exd!=NULL) && (exd->opline != NULL) && (exd->opline->opcode == ZEND_INCLUDE_OR_EVAL)) {
 		int filetype = suhosin_check_filename((char *)filename, strlen(filename) TSRMLS_CC);
@@ -314,11 +303,7 @@ static zend_bool suhosin_zend_open(const char *filename, zend_file_handle *fh)
 			break;
 		}
 	}
-#ifdef ZEND_ENGINE_2
 	return old_zend_stream_open(filename, fh TSRMLS_CC);
-#else
-	return old_zend_open(filename, fh);
-#endif
 }
 
 
@@ -438,7 +423,8 @@ static void suhosin_execute_ex(zend_op_array *op_array, int zo, long dummy TSRML
 		
 			if (*action) {
 			
-				if (strncmp("http://", action, sizeof("http://")-1)==0) {
+				if (strncasecmp("http://", action, sizeof("http://")-1)==0
+				|| strncasecmp("https://", action, sizeof("https://")-1)==0) {
 					sapi_header_line ctr = {0};
 				
 					if (code == -1) {
@@ -458,13 +444,7 @@ static void suhosin_execute_ex(zend_op_array *op_array, int zo, long dummy TSRML
 						code = 200;
 					}
 				
-#ifdef ZEND_ENGINE_2
 					if (zend_stream_open(action, &file_handle TSRMLS_CC) == SUCCESS) {
-#else
-					if (zend_open(action, &file_handle) == SUCCESS && ZEND_IS_VALID_FILE_HANDLE(&file_handle)) {
-						file_handle.filename = action;
-						file_handle.free_filename = 0;
-#endif		
 						if (!file_handle.opened_path) {
 							file_handle.opened_path = estrndup(action, strlen(action));
 						}
@@ -474,15 +454,10 @@ static void suhosin_execute_ex(zend_op_array *op_array, int zo, long dummy TSRML
 							EG(return_value_ptr_ptr) = &result;
 							EG(active_op_array) = new_op_array;
 							zend_execute(new_op_array TSRMLS_CC);
-#ifdef ZEND_ENGINE_2
 							destroy_op_array(new_op_array TSRMLS_CC);
-#else
-							destroy_op_array(new_op_array);
-#endif
 							efree(new_op_array);
-#ifdef ZEND_ENGINE_2
+
 							if (!EG(exception))
-#endif
 							{
 								if (EG(return_value_ptr_ptr)) {
 									zval_ptr_dtor(EG(return_value_ptr_ptr));
@@ -776,7 +751,10 @@ int ih_mail(IH_HANDLER_PARAMS)
 		return (1);
 	}
 
-	if (headers_len > 0 && headers && (strstr(headers,"\n\n") || strstr(headers,"\r\n\r\n")) ) {
+	if (headers_len > 0 && headers &&
+		(strstr(headers, "\n\n") || strstr(headers, "\n\r\n") /* double newline */
+			|| *headers == '\n' || (headers[0] == '\r' && headers[1] == '\n') /* starts with newline */
+	)) {
 		suhosin_log(S_MAIL, "mail() - double newline in headers, possible injection, mail dropped");
 		if (!SUHOSIN_G(simulation)) {
 			RETVAL_FALSE;
@@ -787,14 +765,14 @@ int ih_mail(IH_HANDLER_PARAMS)
 	/* check for spam attempts with buggy webforms */
 	if (to_len > 0 && to) {
 		do {
-			tmp = strchr(to, '\n');
-			tmp = tmp == NULL ? strchr(to, '\r') : tmp;
+			if ((tmp = strchr(to, '\n')) == NULL)
+				tmp = strchr(to, '\r');
 			if (tmp == NULL) break;
-			to = tmp+1;
-			if (isspace(*to)) continue;
+			to = tmp + 1;
+			if (!isspace(*to)) break;
 		} while (1);
 		if (tmp != NULL) {
-			suhosin_log(S_MAIL, "mail() - newline in to header, possible injection, mail dropped");
+			suhosin_log(S_MAIL, "mail() - newline in To header, possible injection, mail dropped");
 			if (!SUHOSIN_G(simulation)) {
 				RETVAL_FALSE;
 				return (1);
@@ -804,14 +782,14 @@ int ih_mail(IH_HANDLER_PARAMS)
 
 	if (subject_len > 0 && subject) {
 		do {
-			tmp = strchr(subject, '\n');
-			tmp = tmp == NULL ? strchr(subject, '\r') : tmp;
+			if ((tmp = strchr(subject, '\n')) == NULL)
+				tmp = strchr(subject, '\r');
 			if (tmp == NULL) break;
-			subject = tmp+1;
-			if (isspace(*subject)) continue;
+			subject = tmp + 1;
+			if (!isspace(*subject)) break;
 		} while (1);
 		if (tmp != NULL) {
-			suhosin_log(S_MAIL, "mail() - newline in subject header, possible injection, mail dropped");
+			suhosin_log(S_MAIL, "mail() - newline in Subject header, possible injection, mail dropped");
 			if (!SUHOSIN_G(simulation)) {
 				RETVAL_FALSE;
 				return (1);
@@ -859,11 +837,7 @@ int ih_mail(IH_HANDLER_PARAMS)
 
 int ih_querycheck(IH_HANDLER_PARAMS)
 {
-#ifdef PHP_ATLEAST_5_3
-    void **p = zend_vm_stack_top(TSRMLS_C) - 1;
-#else
-	void **p = EG(argument_stack).top_element-2;
-#endif
+	void **p = zend_vm_stack_top(TSRMLS_C) - 1;
 	unsigned long arg_count;
 	zval **arg;
 	char *query, *s, *e;
@@ -1020,11 +994,7 @@ int ih_querycheck(IH_HANDLER_PARAMS)
 
 int ih_fixusername(IH_HANDLER_PARAMS)
 {
-#ifdef PHP_ATLEAST_5_3
-    void **p = zend_vm_stack_top(TSRMLS_C) - 1;
-#else
-	void **p = EG(argument_stack).top_element-2;
-#endif
+	void **p = zend_vm_stack_top(TSRMLS_C) - 1;
 	unsigned long arg_count;
 	zval **arg;
 	char *prefix, *postfix, *user, *user_match, *cp;
@@ -1115,15 +1085,12 @@ int ih_fixusername(IH_HANDLER_PARAMS)
 
 static int ih_function_exists(IH_HANDLER_PARAMS)
 {
-#ifndef PHP_ATLEAST_5_3
 	zval **function_name;
-#endif
 	zend_function *func;
 	char *lcname;
 	zend_bool retval;
 	int func_name_len;
 	
-#ifndef PHP_ATLEAST_5_3
 	if (ZEND_NUM_ARGS()!=1 || zend_get_parameters_ex(1, &function_name)==FAILURE) {
 		ZEND_WRONG_PARAM_COUNT_WITH_RETVAL(1);
 	}
@@ -1131,18 +1098,6 @@ static int ih_function_exists(IH_HANDLER_PARAMS)
 	func_name_len = Z_STRLEN_PP(function_name);
 	lcname = estrndup(Z_STRVAL_PP(function_name), func_name_len);	
 	zend_str_tolower(lcname, func_name_len);
-#else
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s", &lcname, &func_name_len) == FAILURE) {
-		return (1);
-	}
-
-	/* Ignore leading "\" */
-	if (func_name_len > 0 && lcname[0] == '\\') {
-		lcname = &lcname[1];
-		func_name_len--;
-	}
-	lcname = zend_str_tolower_dup(lcname, func_name_len);	
-#endif
 
 	retval = (zend_hash_find(EG(function_table), lcname, func_name_len+1, (void **)&func) == SUCCESS);
 	
@@ -1471,42 +1426,46 @@ static php_uint32 suhosin_rand(TSRMLS_D)
 
 static int ih_srand(IH_HANDLER_PARAMS)
 {
-    int argc = ZEND_NUM_ARGS();
+	int argc = ZEND_NUM_ARGS();
 	long seed;
 
-	if (zend_parse_parameters(argc TSRMLS_CC, "|l", &seed) == FAILURE || SUHOSIN_G(srand_ignore)) {
-    	if (SUHOSIN_G(srand_ignore)) {
-    		SUHOSIN_G(r_is_seeded) = 0;
-    	}
-    	return (1);
-    }
+	if (SUHOSIN_G(srand_ignore)) {
+		SUHOSIN_G(r_is_seeded) = 0;
+		return 1;
+	}
+	
+	if (zend_parse_parameters(argc TSRMLS_CC, "|l", &seed) == FAILURE) {
+		return 1;
+	}
 
-    if (argc == 0) {
-        suhosin_srand_auto(TSRMLS_C);
-    } else {
-        suhosin_srand(seed TSRMLS_CC);
-    }
+	if (argc) {
+		suhosin_srand(seed TSRMLS_CC);
+	} else {
+		suhosin_srand_auto(TSRMLS_C);
+	}
 	return (1);
 }
 
 static int ih_mt_srand(IH_HANDLER_PARAMS)
 {
-    int argc = ZEND_NUM_ARGS();
+	int argc = ZEND_NUM_ARGS();
 	long seed;
 
-	if (zend_parse_parameters(argc TSRMLS_CC, "|l", &seed) == FAILURE || SUHOSIN_G(mt_srand_ignore)) {
-    	if (SUHOSIN_G(mt_srand_ignore)) {
-    		SUHOSIN_G(mt_is_seeded) = 0;
-    	}
-    	return (1);
-    }
-    
-    if (argc == 0) {
-        suhosin_mt_srand_auto(TSRMLS_C);
-    } else {
-        suhosin_mt_srand(seed TSRMLS_CC);
-    }
-	return (1);
+	if (SUHOSIN_G(mt_srand_ignore)) {
+		SUHOSIN_G(mt_is_seeded) = 0;
+		return 1;
+	}
+	
+	if (zend_parse_parameters(argc TSRMLS_CC, "|l", &seed) == FAILURE) {
+		return 1;
+	}
+
+	if (argc) {
+		suhosin_mt_srand(seed TSRMLS_CC);
+	} else {
+		suhosin_mt_srand_auto(TSRMLS_C);
+	}
+	return 1;
 }
 
 static int ih_mt_rand(IH_HANDLER_PARAMS)
@@ -1559,17 +1518,9 @@ static int ih_rand(IH_HANDLER_PARAMS)
 
 static int ih_getrandmax(IH_HANDLER_PARAMS)
 {
-#ifdef PHP_ATLEAST_5_3
 	if (zend_parse_parameters_none() == FAILURE) {
 		return(0);
 	}
-#else
-        int argc = ZEND_NUM_ARGS();
-
-        if (argc != 0) {
-		ZEND_WRONG_PARAM_COUNT_WITH_RETVAL(1);
-        }
-#endif    
 	RETVAL_LONG(PHP_MT_RAND_MAX);
 	return (1);
 }
@@ -1716,9 +1667,7 @@ static void suhosin_execute_internal(zend_execute_data *execute_data_ptr, int re
 	zend_class_entry *ce = NULL;
 	internal_function_handler *ih;
 
-#ifdef ZEND_ENGINE_2
 	ce = ((zend_internal_function *) execute_data_ptr->function_state.function)->scope;
-#endif
 	lcname = (char *)((zend_internal_function *) execute_data_ptr->function_state.function)->function_name;
 	function_name_strlen = strlen(lcname);
 	
@@ -1736,15 +1685,7 @@ static void suhosin_execute_internal(zend_execute_data *execute_data_ptr, int re
 	}
 
 #if PHP_VERSION_ID < 50500	
-#ifdef ZEND_ENGINE_2  
-# if PHP_VERSION_ID < 50400
-	return_value = (*(temp_variable *)((char *) execute_data_ptr->Ts + execute_data_ptr->opline->result.u.var)).var.ptr;
-# else
 	return_value = (*(temp_variable *)((char *) execute_data_ptr->Ts + execute_data_ptr->opline->result.var)).var.ptr;
-# endif
-#else
-        return_value = execute_data_ptr->Ts[execute_data_ptr->opline->result.u.var].var.ptr;
-#endif
 #endif
 
 	SDEBUG("function: %s", lcname);
@@ -1895,13 +1836,8 @@ void suhosin_hook_execute(TSRMLS_D)
 	/* Add additional protection layer, that SHOULD
 	   catch ZEND_INCLUDE_OR_EVAL *before* the engine tries
 	   to execute */
-#ifdef ZEND_ENGINE_2
 	old_zend_stream_open = zend_stream_open_function;
 	zend_stream_open_function = suhosin_zend_stream_open;
-#else
-	old_zend_open = zend_open;
-	zend_open = suhosin_zend_open;
-#endif
 	
 }
 /* }}} */
@@ -1932,11 +1868,7 @@ void suhosin_unhook_execute()
 	zend_hash_clean(&ihandler_table);
 	
 	/* remove zend_open protection */
-#ifdef ZEND_ENGINE_2
 	zend_stream_open_function = old_zend_stream_open;
-#else
-	zend_open = old_zend_open;
-#endif
 	
 }
 /* }}} */
