@@ -35,7 +35,6 @@
 #include "suhosin_rfc1867.h"
 #include "ext/standard/php_string.h"
 
-#if PHP_VERSION_ID >= 50400
 
 #define DEBUG_FILE_UPLOAD ZEND_DEBUG
 
@@ -388,6 +387,7 @@ static int multipart_buffer_headers(multipart_buffer *self, zend_llist *header T
 	char *line;
 	mime_header_entry prev_entry = {0}, entry;
 	int prev_len, cur_len;
+	int newlines = 0;
 
 	/* didn't find boundary, abort */
 	if (!find_boundary(self, self->boundary TSRMLS_CC)) {
@@ -417,6 +417,7 @@ static int multipart_buffer_headers(multipart_buffer *self, zend_llist *header T
 
 			entry.value = estrdup(value);
 			entry.key = estrdup(key);
+			newlines = 0;
 
 		} else if (zend_llist_count(header)) { /* If no ':' on the line, add to previous line */
 
@@ -429,6 +430,12 @@ static int multipart_buffer_headers(multipart_buffer *self, zend_llist *header T
 			entry.value[cur_len + prev_len] = '\0';
 
 			entry.key = estrdup(prev_entry.key);
+			newlines++;
+			if (newlines > SUHOSIN_G(upload_max_newlines)) {
+				SUHOSIN_G(abort_request) = 1;
+				suhosin_log(S_FILES, "configured maximum number of newlines in RFC1867 MIME headers limit exceeded - dropping rest of upload");
+				return 0;
+			}
 
 			zend_llist_remove_tail(header);
 		} else {
@@ -1267,7 +1274,6 @@ fileupload_done:
 }
 /* }}} */
 
-#endif
 
 /*
  * Local variables:
