@@ -3,7 +3,7 @@
   | Suhosin Version 1                                                    |
   +----------------------------------------------------------------------+
   | Copyright (c) 2006-2007 The Hardened-PHP Project                     |
-  | Copyright (c) 2007-2014 SektionEins GmbH                             |
+  | Copyright (c) 2007-2015 SektionEins GmbH                             |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
@@ -86,12 +86,6 @@ static PHP_FUNCTION(suhosin_sha256_file)
 		return;
 	}
 
-#if PHP_VERSION_ID < 50400
-	if (PG(safe_mode) && (!php_checkuid(arg, NULL, CHECKUID_CHECK_FILE_AND_DIR))) {
-		RETURN_FALSE;
-	}
-#endif
-
 	if (php_check_open_basedir(arg TSRMLS_CC)) {
 		RETURN_FALSE;
 	}
@@ -410,11 +404,7 @@ void suhosin_hook_sha256(TSRMLS_D)
 	}
 	
 	/* add the sha256 functions */
-#ifndef ZEND_ENGINE_2
-	zend_register_functions(suhosin_sha256_functions, NULL, MODULE_PERSISTENT TSRMLS_CC);
-#else
 	zend_register_functions(NULL, suhosin_sha256_functions, NULL, MODULE_PERSISTENT TSRMLS_CC);
-#endif
 }
 
 
